==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Lisää säädetty ominaisuus</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Arvo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Näytä Z koordinaatit</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translation>*VAIHTELEVA*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Ei valintaa</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Riippuvaiset kohteet</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Hakemisto</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Poista tämä ominaisuus valituilta kohteilta</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Lisää säädetty ominaisuus valittuihin kohteisiin</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translation>Käytä automaattisia mittauksia</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location line="+320"/>
        <source>Widgets</source>
        <translation>Pienoisohjelmat</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Ominaisuuksien muokkaaminen</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Valinta:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Yleistä</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Siirrä valinta uuteen tasoon</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Viivatyypin mittakaava:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Käsittele:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Lisää säädetty ominaisuus</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Arvo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Näytä Z koordinaatit</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translation>*VAIHTELEVA*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translation>Ei valintaa</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Riippuvaiset kohteet</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Hakemisto</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Poista tämä ominaisuus valituilta kohteilta</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Lisää säädetty ominaisuus valittuihin kohteisiin</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Auto</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translation>Käytä automaattisia mittauksia</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location line="+336"/>
        <source>Widgets</source>
        <translation>Pienoisohjelmat</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Ominaisuuksien muokkaaminen</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Valinta:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Yleistä</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Siirrä valinta uuteen tasoon</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Viivatyypin mittakaava:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Käsittele:</translation>
    </message>
</context>
</TS>
